import bisect
import math

LIMIT = int(10**18 + 6 * 10**10)

def czy_jest_kwadratem(X):
    pierwiastek = math.isqrt(X)
    return pierwiastek * pierwiastek == X

# Liczby potęgowe podzielimy na:
#  małe liczby potęgowe (z wykładnikiem równym 2),
#  duże liczby potęgowe (z wykładnikiem większym niż 2).

# Generujemy duże liczby potegowe (z wykładnikiem większym niż 2).
def wygeneruj_duze_potegowe():
    potegowe = []
    baza = 2
    while True:
        aktualna_potega = baza ** 3
        if aktualna_potega > LIMIT:
            break
        while aktualna_potega <= LIMIT:
            # Chcemy mieć jedynie duże liczby potęgowe, więc
            # sprawdzamy czy przez przypadek nie jest kwadratem
            # (tj. małą liczbą potęgową).
            if not czy_jest_kwadratem(aktualna_potega):
                potegowe.append(aktualna_potega)
            aktualna_potega *= baza
        baza += 1
    return sorted(list(set(potegowe)))

# Liczymy ile jest małych liczb potęgowych mniejszych od X.
def ile_mniejszych_malych(X):
    return math.isqrt(X-1) - 1

# Zwraca którą liczbą potęgową jest X.
def ktora_potegowa(X, duze_potegowe):
    mniejszych_malych = ile_mniejszych_malych(X)
    mniejszych_duzych = bisect.bisect_left(duze_potegowe, X)
    return X - mniejszych_malych - mniejszych_duzych

# Używamy wyszukiwania binarnego do znalezienia odpowiedzi.
def wyszukiwanie_binarne(N, duze_potegowe):
    a, b = 1, LIMIT
    while b-a > 1:
        mid = (a+b) // 2
        # Pytamy, którą liczbą niepotęgową jest mid.
        if ktora_potegowa(mid, duze_potegowe) <= N:
            a = mid 
        else:
            b = mid
    return a

def main():
    duze_potegowe = wygeneruj_duze_potegowe()
    T = int(input())
    for _ in range(T):
        N = int(input())
        print(wyszukiwanie_binarne(N, duze_potegowe))

if __name__ == "__main__":
    main()